==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/model/ThisDeviceType.java <==

package org.somda.sdc.dpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;


/**
 * <p>Java class for ThisDeviceType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ThisDeviceType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="FriendlyName" type="{http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01}LocalizedStringType" maxOccurs="unbounded"/&gt;
 *         &lt;element name="FirmwareVersion" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="SerialNumber" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ThisDeviceType", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", propOrder = {
    "friendlyName",
    "firmwareVersion",
    "serialNumber",
    "any"
})
public class ThisDeviceType implements ToString2
{

    @XmlElement(name = "FriendlyName", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", required = true)
    protected List<LocalizedStringType> friendlyName;
    @XmlElement(name = "FirmwareVersion", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01")
    protected String firmwareVersion;
    @XmlElement(name = "SerialNumber", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01")
    protected String serialNumber;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the friendlyName property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the friendlyName property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFriendlyName().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LocalizedStringType }
     * 
     * 
     */
    public List<LocalizedStringType> getFriendlyName() {
        if (friendlyName == null) {
            friendlyName = new ArrayList<LocalizedStringType>();
        }
        return this.friendlyName;
    }

    /**
     * Ruft den Wert der firmwareVersion-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFirmwareVersion() {
        return firmwareVersion;
    }

    /**
     * Legt den Wert der firmwareVersion-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFirmwareVersion(String value) {
        this.firmwareVersion = value;
    }

    /**
     * Ruft den Wert der serialNumber-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSerialNumber() {
        return serialNumber;
    }

    /**
     * Legt den Wert der serialNumber-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSerialNumber(String value) {
        this.serialNumber = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setFriendlyName(List<LocalizedStringType> value) {
        this.friendlyName = null;
        if (value!= null) {
            List<LocalizedStringType> draftl = this.getFriendlyName();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final ThisDeviceType that = ((ThisDeviceType) object);
        {
            List<LocalizedStringType> leftFriendlyName;
            leftFriendlyName = (((this.friendlyName!= null)&&(!this.friendlyName.isEmpty()))?this.getFriendlyName():null);
            List<LocalizedStringType> rightFriendlyName;
            rightFriendlyName = (((that.friendlyName!= null)&&(!that.friendlyName.isEmpty()))?that.getFriendlyName():null);
            if ((this.friendlyName!= null)&&(!this.friendlyName.isEmpty())) {
                if ((that.friendlyName!= null)&&(!that.friendlyName.isEmpty())) {
                    if (!leftFriendlyName.equals(rightFriendlyName)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.friendlyName!= null)&&(!that.friendlyName.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftFirmwareVersion;
            leftFirmwareVersion = this.getFirmwareVersion();
            String rightFirmwareVersion;
            rightFirmwareVersion = that.getFirmwareVersion();
            if (this.firmwareVersion!= null) {
                if (that.firmwareVersion!= null) {
                    if (!leftFirmwareVersion.equals(rightFirmwareVersion)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.firmwareVersion!= null) {
                    return false;
                }
            }
        }
        {
            String leftSerialNumber;
            leftSerialNumber = this.getSerialNumber();
            String rightSerialNumber;
            rightSerialNumber = that.getSerialNumber();
            if (this.serialNumber!= null) {
                if (that.serialNumber!= null) {
                    if (!leftSerialNumber.equals(rightSerialNumber)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.serialNumber!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<LocalizedStringType> theFriendlyName;
            theFriendlyName = (((this.friendlyName!= null)&&(!this.friendlyName.isEmpty()))?this.getFriendlyName():null);
            if ((this.friendlyName!= null)&&(!this.friendlyName.isEmpty())) {
                currentHashCode += theFriendlyName.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theFirmwareVersion;
            theFirmwareVersion = this.getFirmwareVersion();
            if (this.firmwareVersion!= null) {
                currentHashCode += theFirmwareVersion.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theSerialNumber;
            theSerialNumber = this.getSerialNumber();
            if (this.serialNumber!= null) {
                currentHashCode += theSerialNumber.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            List<LocalizedStringType> theFriendlyName;
            theFriendlyName = (((this.friendlyName!= null)&&(!this.friendlyName.isEmpty()))?this.getFriendlyName():null);
            strategy.appendField(locator, this, "friendlyName", buffer, theFriendlyName, ((this.friendlyName!= null)&&(!this.friendlyName.isEmpty())));
        }
        {
            String theFirmwareVersion;
            theFirmwareVersion = this.getFirmwareVersion();
            strategy.appendField(locator, this, "firmwareVersion", buffer, theFirmwareVersion, (this.firmwareVersion!= null));
        }
        {
            String theSerialNumber;
            theSerialNumber = this.getSerialNumber();
            strategy.appendField(locator, this, "serialNumber", buffer, theSerialNumber, (this.serialNumber!= null));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/model/ThisDeviceType.java <==

package org.somda.sdc.dpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;


/**
 * <p>Java class for ThisDeviceType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ThisDeviceType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="FriendlyName" type="{http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01}LocalizedStringType" maxOccurs="unbounded"/&gt;
 *         &lt;element name="FirmwareVersion" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="SerialNumber" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ThisDeviceType", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", propOrder = {
    "friendlyName",
    "firmwareVersion",
    "serialNumber",
    "any"
})
public class ThisDeviceType implements ToString2
{

    @XmlElement(name = "FriendlyName", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", required = true)
    protected List<LocalizedStringType> friendlyName;
    @XmlElement(name = "FirmwareVersion", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01")
    protected String firmwareVersion;
    @XmlElement(name = "SerialNumber", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01")
    protected String serialNumber;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the friendlyName property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the friendlyName property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFriendlyName().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LocalizedStringType }
     * 
     * 
     */
    public List<LocalizedStringType> getFriendlyName() {
        if (friendlyName == null) {
            friendlyName = new ArrayList<LocalizedStringType>();
        }
        return this.friendlyName;
    }

    /**
     * Gets the value of the firmwareVersion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFirmwareVersion() {
        return firmwareVersion;
    }

    /**
     * Sets the value of the firmwareVersion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFirmwareVersion(String value) {
        this.firmwareVersion = value;
    }

    /**
     * Gets the value of the serialNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSerialNumber() {
        return serialNumber;
    }

    /**
     * Sets the value of the serialNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSerialNumber(String value) {
        this.serialNumber = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setFriendlyName(List<LocalizedStringType> value) {
        this.friendlyName = null;
        if (value!= null) {
            List<LocalizedStringType> draftl = this.getFriendlyName();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final ThisDeviceType that = ((ThisDeviceType) object);
        {
            List<LocalizedStringType> leftFriendlyName;
            leftFriendlyName = (((this.friendlyName!= null)&&(!this.friendlyName.isEmpty()))?this.getFriendlyName():null);
            List<LocalizedStringType> rightFriendlyName;
            rightFriendlyName = (((that.friendlyName!= null)&&(!that.friendlyName.isEmpty()))?that.getFriendlyName():null);
            if ((this.friendlyName!= null)&&(!this.friendlyName.isEmpty())) {
                if ((that.friendlyName!= null)&&(!that.friendlyName.isEmpty())) {
                    if (!leftFriendlyName.equals(rightFriendlyName)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.friendlyName!= null)&&(!that.friendlyName.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftFirmwareVersion;
            leftFirmwareVersion = this.getFirmwareVersion();
            String rightFirmwareVersion;
            rightFirmwareVersion = that.getFirmwareVersion();
            if (this.firmwareVersion!= null) {
                if (that.firmwareVersion!= null) {
                    if (!leftFirmwareVersion.equals(rightFirmwareVersion)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.firmwareVersion!= null) {
                    return false;
                }
            }
        }
        {
            String leftSerialNumber;
            leftSerialNumber = this.getSerialNumber();
            String rightSerialNumber;
            rightSerialNumber = that.getSerialNumber();
            if (this.serialNumber!= null) {
                if (that.serialNumber!= null) {
                    if (!leftSerialNumber.equals(rightSerialNumber)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.serialNumber!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<LocalizedStringType> theFriendlyName;
            theFriendlyName = (((this.friendlyName!= null)&&(!this.friendlyName.isEmpty()))?this.getFriendlyName():null);
            if ((this.friendlyName!= null)&&(!this.friendlyName.isEmpty())) {
                currentHashCode += theFriendlyName.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theFirmwareVersion;
            theFirmwareVersion = this.getFirmwareVersion();
            if (this.firmwareVersion!= null) {
                currentHashCode += theFirmwareVersion.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theSerialNumber;
            theSerialNumber = this.getSerialNumber();
            if (this.serialNumber!= null) {
                currentHashCode += theSerialNumber.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            List<LocalizedStringType> theFriendlyName;
            theFriendlyName = (((this.friendlyName!= null)&&(!this.friendlyName.isEmpty()))?this.getFriendlyName():null);
            strategy.appendField(locator, this, "friendlyName", buffer, theFriendlyName, ((this.friendlyName!= null)&&(!this.friendlyName.isEmpty())));
        }
        {
            String theFirmwareVersion;
            theFirmwareVersion = this.getFirmwareVersion();
            strategy.appendField(locator, this, "firmwareVersion", buffer, theFirmwareVersion, (this.firmwareVersion!= null));
        }
        {
            String theSerialNumber;
            theSerialNumber = this.getSerialNumber();
            strategy.appendField(locator, this, "serialNumber", buffer, theSerialNumber, (this.serialNumber!= null));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}
